summaryrefslogtreecommitdiff
path: root/lib/lldp/lldp-const.h
diff options
context:
space:
mode:
authorBen Pfaff <blp@ovn.org>2020-06-17 14:16:08 -0700
committerBen Pfaff <blp@ovn.org>2020-10-21 11:28:24 -0700
commit91fc374a9c5a2a4d9520aaa3588a7a18338a476e (patch)
tree36e097d0f7b655e90179c04e21eb7fe4c400889b /lib/lldp/lldp-const.h
parentf51cf36d86e4a51630dc2781034149c13a634d67 (diff)
downloadopenvswitch-91fc374a9c5a2a4d9520aaa3588a7a18338a476e.tar.gz
Eliminate use of term "slave" in bond, LACP, and bundle contexts.
The new term is "member". Most of these changes should not change user-visible behavior. One place where they do is in "ovs-ofctl dump-flows", which will now output "members:..." inside "bundle" actions instead of "slaves:...". I don't expect this to cause real problems in most systems. The old syntax is still supported on input for backward compatibility. Signed-off-by: Ben Pfaff <blp@ovn.org> Acked-by: Alin Gabriel Serdean <aserdean@cloudbasesolutions.com>
Diffstat (limited to 'lib/lldp/lldp-const.h')
-rw-r--r--lib/lldp/lldp-const.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/lib/lldp/lldp-const.h b/lib/lldp/lldp-const.h
index eceb612d1..8c5c0733e 100644
--- a/lib/lldp/lldp-const.h
+++ b/lib/lldp/lldp-const.h
@@ -218,13 +218,13 @@
#define LLDPD_MODE_MAX LLDPD_MODE_FDP
-/* Bond slave src mac type constants */
-#define LLDP_BOND_SLAVE_SRC_MAC_TYPE_UNKNOWN 0
-#define LLDP_BOND_SLAVE_SRC_MAC_TYPE_REAL 1
-#define LLDP_BOND_SLAVE_SRC_MAC_TYPE_ZERO 2
-#define LLDP_BOND_SLAVE_SRC_MAC_TYPE_FIXED 3
-#define LLDP_BOND_SLAVE_SRC_MAC_TYPE_LOCALLY_ADMINISTERED 4
-#define LLDP_BOND_SLAVE_SRC_MAC_TYPE_MAX \
- LLDP_BOND_SLAVE_SRC_MAC_TYPE_LOCALLY_ADMINISTERED
+/* Bond member src mac type constants */
+#define LLDP_BOND_MEMBER_SRC_MAC_TYPE_UNKNOWN 0
+#define LLDP_BOND_MEMBER_SRC_MAC_TYPE_REAL 1
+#define LLDP_BOND_MEMBER_SRC_MAC_TYPE_ZERO 2
+#define LLDP_BOND_MEMBER_SRC_MAC_TYPE_FIXED 3
+#define LLDP_BOND_MEMBER_SRC_MAC_TYPE_LOCALLY_ADMINISTERED 4
+#define LLDP_BOND_MEMBER_SRC_MAC_TYPE_MAX \
+ LLDP_BOND_MEMBER_SRC_MAC_TYPE_LOCALLY_ADMINISTERED
#endif /* _LLDP_H */